# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: onexfabricapi.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='onexfabricapi.proto',
  package='onexfabricapi',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x13onexfabricapi.proto\x12\ronexfabricapi\x1a google/protobuf/descriptor.proto\x1a\x1bgoogle/protobuf/empty.proto\"$\n\rOpenApiMsgOpt\x12\x13\n\x0b\x64\x65scription\x18\n \x01(\t\"5\n\rOpenApiFldOpt\x12\x0f\n\x07\x64\x65\x66\x61ult\x18\n \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x14 \x01(\t\"$\n\rOpenApiSvcOpt\x12\x13\n\x0b\x64\x65scription\x18\n \x01(\t\"$\n\rOpenApiRpcOpt\x12\x13\n\x0b\x64\x65scription\x18\n \x01(\t\"|\n\x11GlobalNamedObject\x12\x39\n\x04name\x18\x01 \x01(\tB&\x92\xa6\x1d\"\xa2\x01\x1fUnique identifier for an objectH\x00\x88\x01\x01:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\x07\n\x05_name\"i\n\x0c\x45rrorDetails\x12\x34\n\x06\x65rrors\x18\x01 \x03(\tB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in models:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in models\"m\n\x0eWarningDetails\x12\x36\n\x08warnings\x18\x01 \x03(\tB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in models:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in models\"\xd4\x01\n\x06\x43onfig\x12H\n\x05hosts\x18\x01 \x03(\x0b\x32\x13.onexfabricapi.HostB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in models\x12P\n\x06\x66\x61\x62ric\x18\x02 \x01(\x0b\x32\x15.onexfabricapi.FabricB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x00\x88\x01\x01:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\t\n\x07_fabric\"\xe6\x01\n\x04Host\x12<\n\x04name\x18\x01 \x01(\tB.\x92\xa6\x1d*\xa2\x01\'The name, uniquely identifying the host\x12\x34\n\x07\x61\x64\x64ress\x18\x02 \x01(\tB#\x92\xa6\x1d\x1f\xa2\x01\x1cThe test address of the host\x12:\n\x06prefix\x18\x03 \x01(\x05\x42%\x92\xa6\x1d\x04R\x02\x32\x34\x92\xa6\x1d\x19\xa2\x01\x16The prefix of the hostH\x00\x88\x01\x01:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\t\n\x07_prefix\"\xb1\x03\n\x06\x46\x61\x62ric\x12\\\n\x06\x63hoice\x18\x01 \x01(\x0e\x32!.onexfabricapi.Fabric.Choice.EnumB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x00\x88\x01\x01\x12\x64\n\x0espine_pod_rack\x18\x02 \x01(\x0b\x32!.onexfabricapi.FabricSpinePodRackB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x01\x88\x01\x01\x12i\n\x0cqos_profiles\x18\x03 \x03(\x0b\x32\x1f.onexfabricapi.FabricQosProfileB2\x92\xa6\x1d.\xa2\x01+A list of Quality of Service (QoS) profiles\x1a\x35\n\x06\x43hoice\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x12\n\x0espine_pod_rack\x10\x01:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\t\n\x07_choiceB\x11\n\x0f_spine_pod_rack\"\xe7\x03\n\x12\x46\x61\x62ricSpinePodRack\x12N\n\x06spines\x18\x01 \x03(\x0b\x32\x1a.onexfabricapi.FabricSpineB\"\x92\xa6\x1d\x1e\xa2\x01\x1bThe spines in the topology.\x12H\n\x04pods\x18\x02 \x03(\x0b\x32\x18.onexfabricapi.FabricPodB \x92\xa6\x1d\x1c\xa2\x01\x19The pods in the topology.\x12W\n\nhost_links\x18\x03 \x03(\x0b\x32\x1d.onexfabricapi.SwitchHostLinkB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in models\x12T\n\x0cpod_profiles\x18\x04 \x03(\x0b\x32\x1f.onexfabricapi.FabricPodProfileB\x1d\x92\xa6\x1d\x19\xa2\x01\x16\x41 list of pod profiles\x12W\n\rrack_profiles\x18\x05 \x03(\x0b\x32 .onexfabricapi.FabricRackProfileB\x1e\x92\xa6\x1d\x1a\xa2\x01\x17\x41 list of rack profiles:/\x8a\xa6\x1d+R)An emulation of a spine/pod/rack topology\"\xe6\x06\n\x0b\x46\x61\x62ricSpine\x12\x9a\x01\n\x05\x63ount\x18\x01 \x01(\x05\x42\x85\x01\x92\xa6\x1d\x03R\x01\x31\x92\xa6\x1dz\xa2\x01wThe number of spines to be created with each spine sharing the same\ndownlink_ecmp_mode and qos_profile_name properties.H\x00\x88\x01\x01\x12\xe1\x02\n\x12\x64ownlink_ecmp_mode\x18\x02 \x01(\x0e\x32\x30.onexfabricapi.FabricSpine.DownlinkEcmpMode.EnumB\x8d\x02\x92\xa6\x1d\x88\x02\xa2\x01\x84\x02The algorithm for packet distribution over ECMP links.\n- random_spray randomly puts each packet on an ECMP member links \n- hash_3_tuple is a 3 tuple hash of ipv4 src, dst, protocol\n- hash_5_tuple is static_hash_ipv4_l4 but a different resulting RTAG7 hash modeH\x01\x88\x01\x01\x12\x97\x01\n\x10qos_profile_name\x18\x03 \x01(\tBx\x92\xa6\x1dt\xa2\x01qThe name of a qos profile shared by the spines.\n\nx-constraint:\n- #/components/schemas/QosProfile/properties/name\nH\x02\x88\x01\x01\x1a\x61\n\x10\x44ownlinkEcmpMode\"M\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x10\n\x0crandom_spray\x10\x01\x12\x10\n\x0chash_3_tuple\x10\x02\x12\x10\n\x0chash_5_tuple\x10\x03:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\x08\n\x06_countB\x15\n\x13_downlink_ecmp_modeB\x13\n\x11_qos_profile_name\"\xdd\x01\n\tFabricPod\x12U\n\x05\x63ount\x18\x01 \x01(\x05\x42\x41\x92\xa6\x1d\x03R\x01\x31\x92\xa6\x1d\x36\xa2\x01\x33The number of pods that will share the same profileH\x00\x88\x01\x01\x12J\n\x10pod_profile_name\x18\x02 \x03(\tB0\x92\xa6\x1d,\xa2\x01)The pod profile associated with this pod.:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\x08\n\x06_count\"\xc4\x02\n\x10\x46\x61\x62ricPodProfile\x12\x37\n\x04name\x18\x01 \x01(\tB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x00\x88\x01\x01\x12]\n\npod_switch\x18\x02 \x01(\x0b\x32\x1e.onexfabricapi.FabricPodSwitchB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x01\x88\x01\x01\x12R\n\x04rack\x18\x03 \x01(\x0b\x32\x19.onexfabricapi.FabricRackB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x02\x88\x01\x01:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\x07\n\x05_nameB\r\n\x0b_pod_switchB\x07\n\x05_rack\"\xf9\n\n\x0f\x46\x61\x62ricPodSwitch\x12?\n\x05\x63ount\x18\x01 \x01(\x05\x42+\x92\xa6\x1d\x03R\x01\x31\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x00\x88\x01\x01\x12]\n\x1dpod_to_spine_oversubscription\x18\x02 \x01(\tB1\x92\xa6\x1d-\xa2\x01*oversubscription ratio of the pod switchesH\x01\x88\x01\x01\x12\xe1\x02\n\x10uplink_ecmp_mode\x18\x03 \x01(\x0e\x32\x32.onexfabricapi.FabricPodSwitch.UplinkEcmpMode.EnumB\x8d\x02\x92\xa6\x1d\x88\x02\xa2\x01\x84\x02The algorithm for packet distribution over ECMP links.\n- random_spray randomly puts each packet on an ECMP member links \n- hash_3_tuple is a 3 tuple hash of ipv4 src, dst, protocol\n- hash_5_tuple is static_hash_ipv4_l4 but a different resulting RTAG7 hash modeH\x02\x88\x01\x01\x12\xe5\x02\n\x12\x64ownlink_ecmp_mode\x18\x04 \x01(\x0e\x32\x34.onexfabricapi.FabricPodSwitch.DownlinkEcmpMode.EnumB\x8d\x02\x92\xa6\x1d\x88\x02\xa2\x01\x84\x02The algorithm for packet distribution over ECMP links.\n- random_spray randomly puts each packet on an ECMP member links \n- hash_3_tuple is a 3 tuple hash of ipv4 src, dst, protocol\n- hash_5_tuple is static_hash_ipv4_l4 but a different resulting RTAG7 hash modeH\x03\x88\x01\x01\x12\xa3\x01\n\x10qos_profile_name\x18\x05 \x01(\tB\x83\x01\x92\xa6\x1d\x7f\xa2\x01|The name of a qos profile associated with this pod switch.\n\nx-constraint:\n- #/components/schemas/QosProfile/properties/name\nH\x04\x88\x01\x01\x1a_\n\x0eUplinkEcmpMode\"M\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x10\n\x0crandom_spray\x10\x01\x12\x10\n\x0chash_3_tuple\x10\x02\x12\x10\n\x0chash_5_tuple\x10\x03\x1a\x61\n\x10\x44ownlinkEcmpMode\"M\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x10\n\x0crandom_spray\x10\x01\x12\x10\n\x0chash_3_tuple\x10\x02\x12\x10\n\x0chash_5_tuple\x10\x03:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\x08\n\x06_countB \n\x1e_pod_to_spine_oversubscriptionB\x13\n\x11_uplink_ecmp_modeB\x15\n\x13_downlink_ecmp_modeB\x13\n\x11_qos_profile_name\"\xe3\x01\n\nFabricRack\x12L\n\x05\x63ount\x18\x01 \x01(\x05\x42\x38\x92\xa6\x1d\x03R\x01\x31\x92\xa6\x1d-\xa2\x01*number of racks (and thus ToRs) in the podH\x00\x88\x01\x01\x12X\n\x12rack_profile_names\x18\x02 \x03(\tB<\x92\xa6\x1d\x38\xa2\x01\x35The names of rack profiles associated with this rack.:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\x08\n\x06_count\"\x9e\x0b\n\x11\x46\x61\x62ricRackProfile\x12\x37\n\x04name\x18\x01 \x01(\tB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x00\x88\x01\x01\x12\xea\x02\n\x14tor_uplink_ecmp_mode\x18\x02 \x01(\x0e\x32\x37.onexfabricapi.FabricRackProfile.TorUplinkEcmpMode.EnumB\x8d\x02\x92\xa6\x1d\x88\x02\xa2\x01\x84\x02The algorithm for packet distribution over ECMP links.\n- random_spray randomly puts each packet on an ECMP member links \n- hash_3_tuple is a 3 tuple hash of ipv4 src, dst, protocol\n- hash_5_tuple is static_hash_ipv4_l4 but a different resulting RTAG7 hash modeH\x01\x88\x01\x01\x12\xee\x02\n\x16tor_downlink_ecmp_mode\x18\x03 \x01(\x0e\x32\x39.onexfabricapi.FabricRackProfile.TorDownlinkEcmpMode.EnumB\x8d\x02\x92\xa6\x1d\x88\x02\xa2\x01\x84\x02The algorithm for packet distribution over ECMP links.\n- random_spray randomly puts each packet on an ECMP member links \n- hash_3_tuple is a 3 tuple hash of ipv4 src, dst, protocol\n- hash_5_tuple is static_hash_ipv4_l4 but a different resulting RTAG7 hash modeH\x02\x88\x01\x01\x12\xad\x01\n\x14tor_qos_profile_name\x18\x04 \x01(\tB\x89\x01\x92\xa6\x1d\x84\x01\xa2\x01\x80\x01The name of a qos profile associated with the ToR of this rack\n\nx-constraint:\n- #/components/schemas/QosProfile/properties/name\nH\x03\x88\x01\x01\x12]\n\x1btor_to_pod_oversubscription\x18\x05 \x01(\tB3\x92\xa6\x1d/\xa2\x01,The oversubscription ratio of the ToR switchH\x04\x88\x01\x01\x1a\x62\n\x11TorUplinkEcmpMode\"M\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x10\n\x0crandom_spray\x10\x01\x12\x10\n\x0chash_3_tuple\x10\x02\x12\x10\n\x0chash_5_tuple\x10\x03\x1a\x64\n\x13TorDownlinkEcmpMode\"M\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x10\n\x0crandom_spray\x10\x01\x12\x10\n\x0chash_3_tuple\x10\x02\x12\x10\n\x0chash_5_tuple\x10\x03:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\x07\n\x05_nameB\x17\n\x15_tor_uplink_ecmp_modeB\x19\n\x17_tor_downlink_ecmp_modeB\x17\n\x15_tor_qos_profile_nameB\x1e\n\x1c_tor_to_pod_oversubscription\"\x87\x04\n\x10\x46\x61\x62ricQosProfile\x12\x32\n\x04name\x18\x01 \x01(\tB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in models\x12u\n\x11ingress_admission\x18\x02 \x01(\x0b\x32/.onexfabricapi.FabricQosProfileIngressAdmissionB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x00\x88\x01\x01\x12\x66\n\tscheduler\x18\x03 \x01(\x0b\x32(.onexfabricapi.FabricQosProfileSchedulerB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x01\x88\x01\x01\x12}\n\x15packet_classification\x18\x04 \x01(\x0b\x32\x33.onexfabricapi.FabricQosProfilePacketClassificationB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x02\x88\x01\x01:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\x14\n\x12_ingress_admissionB\x0c\n\n_schedulerB\x18\n\x16_packet_classification\"\xe1\x02\n FabricQosProfileIngressAdmission\x12\x81\x01\n\x15reserved_buffer_bytes\x18\x01 \x01(\x05\x42]\x92\xa6\x1d\x03R\x01\x30\x92\xa6\x1dR\xa2\x01OBuffer space (in bytes) reserved for each port that this Qos profile applies toH\x00\x88\x01\x01\x12\x62\n\x13shared_buffer_bytes\x18\x02 \x01(\x05\x42@\x92\xa6\x1d\x03R\x01\x30\x92\xa6\x1d\x35\xa2\x01\x32\x41mount of shared buffer space (in bytes) availableH\x01\x88\x01\x01:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\x18\n\x16_reserved_buffer_bytesB\x16\n\x14_shared_buffer_bytes\"\xe5\x02\n\x19\x46\x61\x62ricQosProfileScheduler\x12\x81\x01\n\x0escheduler_mode\x18\x01 \x01(\x0e\x32;.onexfabricapi.FabricQosProfileScheduler.SchedulerMode.EnumB\'\x92\xa6\x1d#\xa2\x01 The queue scheduling discipline H\x00\x88\x01\x01\x12\x33\n\x0bweight_list\x18\x02 \x03(\x05\x42\x1e\x92\xa6\x1d\x1a\xa2\x01\x17\x41 list of queue weights\x1aW\n\rSchedulerMode\"F\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x13\n\x0fstrict_priority\x10\x01\x12\x18\n\x14weighted_round_robin\x10\x02:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\x11\n\x0f_scheduler_mode\"\x97\x03\n$FabricQosProfilePacketClassification\x12\x84\x01\n\x19map_dscp_to_traffic_class\x18\x01 \x01(\x0b\x32\x36.onexfabricapi.FabricQosProfilePacketClassificationMapB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x00\x88\x01\x01\x12\x85\x01\n\x1amap_traffic_class_to_queue\x18\x02 \x01(\x0b\x32\x36.onexfabricapi.FabricQosProfilePacketClassificationMapB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x01\x88\x01\x01:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\x1c\n\x1a_map_dscp_to_traffic_classB\x1d\n\x1b_map_traffic_class_to_queue\"N\n\'FabricQosProfilePacketClassificationMap:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in models\"\xfa\x06\n\x0eSwitchHostLink\x12X\n\thost_name\x18\x01 \x01(\tBE\x92\xa6\x1d\x41\xa2\x01>TBD\n\nx-constraint:\n- #components/schemas/Host/properties/name\n\x12m\n\x10\x66ront_panel_port\x18\x02 \x01(\x05\x42N\x92\xa6\x1dJ\xa2\x01GOptional front panel port number, if fabric is rendered on physical boxH\x00\x88\x01\x01\x12z\n\x06\x63hoice\x18\x03 \x01(\x0e\x32).onexfabricapi.SwitchHostLink.Choice.EnumB:\x92\xa6\x1d\x12R\x10\x43hoice.Enum.rack\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x01\x88\x01\x01\x12\x88\x01\n\x05spine\x18\x04 \x01(\x05\x42t\x92\xa6\x1dp\xa2\x01mOne based index of the spine switch based on the number of spines \nconfigured in the spine_pod_rack topology.H\x02\x88\x01\x01\x12^\n\x03pod\x18\x05 \x01(\x0b\x32&.onexfabricapi.SwitchHostLinkSwitchRefB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x03\x88\x01\x01\x12_\n\x04rack\x18\x06 \x01(\x0b\x32&.onexfabricapi.SwitchHostLinkSwitchRefB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x04\x88\x01\x01\x1a?\n\x06\x43hoice\"5\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05spine\x10\x01\x12\x07\n\x03pod\x10\x02\x12\x08\n\x04rack\x10\x03:[\x8a\xa6\x1dWRUThe ingress point of a host which is the index of a spine switch, \na pod/rack switch.B\x13\n\x11_front_panel_portB\t\n\x07_choiceB\x08\n\x06_spineB\x06\n\x04_podB\x07\n\x05_rack\"\xc9\x02\n\x17SwitchHostLinkSwitchRef\x12j\n\tpod_index\x18\x01 \x01(\x05\x42R\x92\xa6\x1d\x03R\x01\x31\x92\xa6\x1dG\xa2\x01\x44One-based index of the pod based on the number of pods in the fabricH\x00\x88\x01\x01\x12g\n\x0cswitch_index\x18\x02 \x01(\x05\x42L\x92\xa6\x1d\x03R\x01\x31\x92\xa6\x1d\x41\xa2\x01>One-based index of the pod or rack switch in the indicated podH\x01\x88\x01\x01::\x8a\xa6\x1d\x36R4Location of the switch based on pod and switch indexB\x0c\n\n_pod_indexB\x0f\n\r_switch_index\"9\n\x10SetConfigRequest\x12%\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x15.onexfabricapi.Config\"\x82\x02\n\x11SetConfigResponse\x12\x39\n\x0fstatus_code_400\x18\x01 \x01(\x0b\x32\x1b.onexfabricapi.ErrorDetailsH\x00\x88\x01\x01\x12\x39\n\x0fstatus_code_500\x18\x02 \x01(\x0b\x32\x1b.onexfabricapi.ErrorDetailsH\x01\x88\x01\x01\x12;\n\x0fstatus_code_200\x18\x03 \x01(\x0b\x32\x1d.onexfabricapi.WarningDetailsH\x02\x88\x01\x01\x42\x12\n\x10_status_code_400B\x12\n\x10_status_code_500B\x12\n\x10_status_code_200\"\xfa\x01\n\x11GetConfigResponse\x12\x33\n\x0fstatus_code_200\x18\x01 \x01(\x0b\x32\x15.onexfabricapi.ConfigH\x00\x88\x01\x01\x12\x39\n\x0fstatus_code_400\x18\x02 \x01(\x0b\x32\x1b.onexfabricapi.ErrorDetailsH\x01\x88\x01\x01\x12\x39\n\x0fstatus_code_500\x18\x03 \x01(\x0b\x32\x1b.onexfabricapi.ErrorDetailsH\x02\x88\x01\x01\x42\x12\n\x10_status_code_200B\x12\n\x10_status_code_400B\x12\n\x10_status_code_5002\x91\x02\n\x07Openapi\x12t\n\tSetConfig\x12\x1f.onexfabricapi.SetConfigRequest\x1a .onexfabricapi.SetConfigResponse\"$\xa2\xa6\x1d R\x1eSets the fabric configuration.\x12k\n\tGetConfig\x12\x16.google.protobuf.Empty\x1a .onexfabricapi.GetConfigResponse\"$\xa2\xa6\x1d R\x1eGets the fabric configuration.\x1a#\x9a\xa6\x1d\x1fR\x1d\x44\x65scription missing in models:T\n\x08msg_meta\x12\x1f.google.protobuf.MessageOptions\x18\xe1\xd4\x03 \x01(\x0b\x32\x1c.onexfabricapi.OpenApiMsgOpt\x88\x01\x01:R\n\x08\x66ld_meta\x12\x1d.google.protobuf.FieldOptions\x18\xe2\xd4\x03 \x01(\x0b\x32\x1c.onexfabricapi.OpenApiFldOpt\x88\x01\x01:T\n\x08svc_meta\x12\x1f.google.protobuf.ServiceOptions\x18\xe3\xd4\x03 \x01(\x0b\x32\x1c.onexfabricapi.OpenApiSvcOpt\x88\x01\x01:S\n\x08rpc_meta\x12\x1e.google.protobuf.MethodOptions\x18\xe4\xd4\x03 \x01(\x0b\x32\x1c.onexfabricapi.OpenApiRpcOpt\x88\x01\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_descriptor__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,])


MSG_META_FIELD_NUMBER = 60001
msg_meta = _descriptor.FieldDescriptor(
  name='msg_meta', full_name='onexfabricapi.msg_meta', index=0,
  number=60001, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
FLD_META_FIELD_NUMBER = 60002
fld_meta = _descriptor.FieldDescriptor(
  name='fld_meta', full_name='onexfabricapi.fld_meta', index=1,
  number=60002, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
SVC_META_FIELD_NUMBER = 60003
svc_meta = _descriptor.FieldDescriptor(
  name='svc_meta', full_name='onexfabricapi.svc_meta', index=2,
  number=60003, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
RPC_META_FIELD_NUMBER = 60004
rpc_meta = _descriptor.FieldDescriptor(
  name='rpc_meta', full_name='onexfabricapi.rpc_meta', index=3,
  number=60004, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)

_FABRIC_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='onexfabricapi.Fabric.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='spine_pod_rack', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1386,
  serialized_end=1429,
)
_sym_db.RegisterEnumDescriptor(_FABRIC_CHOICE_ENUM)

_FABRICSPINE_DOWNLINKECMPMODE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='onexfabricapi.FabricSpine.DownlinkEcmpMode.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='random_spray', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='hash_3_tuple', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='hash_5_tuple', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2691,
  serialized_end=2768,
)
_sym_db.RegisterEnumDescriptor(_FABRICSPINE_DOWNLINKECMPMODE_ENUM)

_FABRICPODSWITCH_UPLINKECMPMODE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='onexfabricapi.FabricPodSwitch.UplinkEcmpMode.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='random_spray', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='hash_3_tuple', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='hash_5_tuple', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2691,
  serialized_end=2768,
)
_sym_db.RegisterEnumDescriptor(_FABRICPODSWITCH_UPLINKECMPMODE_ENUM)

_FABRICPODSWITCH_DOWNLINKECMPMODE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='onexfabricapi.FabricPodSwitch.DownlinkEcmpMode.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='random_spray', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='hash_3_tuple', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='hash_5_tuple', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2691,
  serialized_end=2768,
)
_sym_db.RegisterEnumDescriptor(_FABRICPODSWITCH_DOWNLINKECMPMODE_ENUM)

_FABRICRACKPROFILE_TORUPLINKECMPMODE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='onexfabricapi.FabricRackProfile.TorUplinkEcmpMode.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='random_spray', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='hash_3_tuple', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='hash_5_tuple', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2691,
  serialized_end=2768,
)
_sym_db.RegisterEnumDescriptor(_FABRICRACKPROFILE_TORUPLINKECMPMODE_ENUM)

_FABRICRACKPROFILE_TORDOWNLINKECMPMODE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='onexfabricapi.FabricRackProfile.TorDownlinkEcmpMode.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='random_spray', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='hash_3_tuple', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='hash_5_tuple', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2691,
  serialized_end=2768,
)
_sym_db.RegisterEnumDescriptor(_FABRICRACKPROFILE_TORDOWNLINKECMPMODE_ENUM)

_FABRICQOSPROFILESCHEDULER_SCHEDULERMODE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='onexfabricapi.FabricQosProfileScheduler.SchedulerMode.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='strict_priority', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='weighted_round_robin', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7597,
  serialized_end=7667,
)
_sym_db.RegisterEnumDescriptor(_FABRICQOSPROFILESCHEDULER_SCHEDULERMODE_ENUM)

_SWITCHHOSTLINK_CHOICE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='onexfabricapi.SwitchHostLink.Choice.Enum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='spine', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='pod', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='rack', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8901,
  serialized_end=8954,
)
_sym_db.RegisterEnumDescriptor(_SWITCHHOSTLINK_CHOICE_ENUM)


_OPENAPIMSGOPT = _descriptor.Descriptor(
  name='OpenApiMsgOpt',
  full_name='onexfabricapi.OpenApiMsgOpt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='description', full_name='onexfabricapi.OpenApiMsgOpt.description', index=0,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=101,
  serialized_end=137,
)


_OPENAPIFLDOPT = _descriptor.Descriptor(
  name='OpenApiFldOpt',
  full_name='onexfabricapi.OpenApiFldOpt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='default', full_name='onexfabricapi.OpenApiFldOpt.default', index=0,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='onexfabricapi.OpenApiFldOpt.description', index=1,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=139,
  serialized_end=192,
)


_OPENAPISVCOPT = _descriptor.Descriptor(
  name='OpenApiSvcOpt',
  full_name='onexfabricapi.OpenApiSvcOpt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='description', full_name='onexfabricapi.OpenApiSvcOpt.description', index=0,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=194,
  serialized_end=230,
)


_OPENAPIRPCOPT = _descriptor.Descriptor(
  name='OpenApiRpcOpt',
  full_name='onexfabricapi.OpenApiRpcOpt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='description', full_name='onexfabricapi.OpenApiRpcOpt.description', index=0,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=232,
  serialized_end=268,
)


_GLOBALNAMEDOBJECT = _descriptor.Descriptor(
  name='GlobalNamedObject',
  full_name='onexfabricapi.GlobalNamedObject',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='onexfabricapi.GlobalNamedObject.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035\"\242\001\037Unique identifier for an object', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\212\246\035\037R\035Description missing in models',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_name', full_name='onexfabricapi.GlobalNamedObject._name',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=270,
  serialized_end=394,
)


_ERRORDETAILS = _descriptor.Descriptor(
  name='ErrorDetails',
  full_name='onexfabricapi.ErrorDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='errors', full_name='onexfabricapi.ErrorDetails.errors', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035 \242\001\035Description missing in models', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\212\246\035\037R\035Description missing in models',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=396,
  serialized_end=501,
)


_WARNINGDETAILS = _descriptor.Descriptor(
  name='WarningDetails',
  full_name='onexfabricapi.WarningDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='warnings', full_name='onexfabricapi.WarningDetails.warnings', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035 \242\001\035Description missing in models', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\212\246\035\037R\035Description missing in models',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=503,
  serialized_end=612,
)


_CONFIG = _descriptor.Descriptor(
  name='Config',
  full_name='onexfabricapi.Config',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hosts', full_name='onexfabricapi.Config.hosts', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035 \242\001\035Description missing in models', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fabric', full_name='onexfabricapi.Config.fabric', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035 \242\001\035Description missing in models', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\212\246\035\037R\035Description missing in models',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_fabric', full_name='onexfabricapi.Config._fabric',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=615,
  serialized_end=827,
)


_HOST = _descriptor.Descriptor(
  name='Host',
  full_name='onexfabricapi.Host',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='onexfabricapi.Host.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035*\242\001\'The name, uniquely identifying the host', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='address', full_name='onexfabricapi.Host.address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035\037\242\001\034The test address of the host', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prefix', full_name='onexfabricapi.Host.prefix', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035\004R\00224\222\246\035\031\242\001\026The prefix of the host', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\212\246\035\037R\035Description missing in models',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_prefix', full_name='onexfabricapi.Host._prefix',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=830,
  serialized_end=1060,
)


_FABRIC_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='onexfabricapi.Fabric.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FABRIC_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1376,
  serialized_end=1429,
)

_FABRIC = _descriptor.Descriptor(
  name='Fabric',
  full_name='onexfabricapi.Fabric',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='choice', full_name='onexfabricapi.Fabric.choice', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035 \242\001\035Description missing in models', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spine_pod_rack', full_name='onexfabricapi.Fabric.spine_pod_rack', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035 \242\001\035Description missing in models', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qos_profiles', full_name='onexfabricapi.Fabric.qos_profiles', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035.\242\001+A list of Quality of Service (QoS) profiles', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FABRIC_CHOICE, ],
  enum_types=[
  ],
  serialized_options=b'\212\246\035\037R\035Description missing in models',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_choice', full_name='onexfabricapi.Fabric._choice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_spine_pod_rack', full_name='onexfabricapi.Fabric._spine_pod_rack',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1063,
  serialized_end=1496,
)


_FABRICSPINEPODRACK = _descriptor.Descriptor(
  name='FabricSpinePodRack',
  full_name='onexfabricapi.FabricSpinePodRack',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='spines', full_name='onexfabricapi.FabricSpinePodRack.spines', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035\036\242\001\033The spines in the topology.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pods', full_name='onexfabricapi.FabricSpinePodRack.pods', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035\034\242\001\031The pods in the topology.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host_links', full_name='onexfabricapi.FabricSpinePodRack.host_links', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035 \242\001\035Description missing in models', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pod_profiles', full_name='onexfabricapi.FabricSpinePodRack.pod_profiles', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035\031\242\001\026A list of pod profiles', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rack_profiles', full_name='onexfabricapi.FabricSpinePodRack.rack_profiles', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035\032\242\001\027A list of rack profiles', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\212\246\035+R)An emulation of a spine/pod/rack topology',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1499,
  serialized_end=1986,
)


_FABRICSPINE_DOWNLINKECMPMODE = _descriptor.Descriptor(
  name='DownlinkEcmpMode',
  full_name='onexfabricapi.FabricSpine.DownlinkEcmpMode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FABRICSPINE_DOWNLINKECMPMODE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2671,
  serialized_end=2768,
)

_FABRICSPINE = _descriptor.Descriptor(
  name='FabricSpine',
  full_name='onexfabricapi.FabricSpine',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='count', full_name='onexfabricapi.FabricSpine.count', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035\003R\0011\222\246\035z\242\001wThe number of spines to be created with each spine sharing the same\ndownlink_ecmp_mode and qos_profile_name properties.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='downlink_ecmp_mode', full_name='onexfabricapi.FabricSpine.downlink_ecmp_mode', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035\210\002\242\001\204\002The algorithm for packet distribution over ECMP links.\n- random_spray randomly puts each packet on an ECMP member links \n- hash_3_tuple is a 3 tuple hash of ipv4 src, dst, protocol\n- hash_5_tuple is static_hash_ipv4_l4 but a different resulting RTAG7 hash mode', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qos_profile_name', full_name='onexfabricapi.FabricSpine.qos_profile_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035t\242\001qThe name of a qos profile shared by the spines.\n\nx-constraint:\n- #/components/schemas/QosProfile/properties/name\n', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FABRICSPINE_DOWNLINKECMPMODE, ],
  enum_types=[
  ],
  serialized_options=b'\212\246\035\037R\035Description missing in models',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_count', full_name='onexfabricapi.FabricSpine._count',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_downlink_ecmp_mode', full_name='onexfabricapi.FabricSpine._downlink_ecmp_mode',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_qos_profile_name', full_name='onexfabricapi.FabricSpine._qos_profile_name',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1989,
  serialized_end=2859,
)


_FABRICPOD = _descriptor.Descriptor(
  name='FabricPod',
  full_name='onexfabricapi.FabricPod',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='count', full_name='onexfabricapi.FabricPod.count', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035\003R\0011\222\246\0356\242\0013The number of pods that will share the same profile', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pod_profile_name', full_name='onexfabricapi.FabricPod.pod_profile_name', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035,\242\001)The pod profile associated with this pod.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\212\246\035\037R\035Description missing in models',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_count', full_name='onexfabricapi.FabricPod._count',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2862,
  serialized_end=3083,
)


_FABRICPODPROFILE = _descriptor.Descriptor(
  name='FabricPodProfile',
  full_name='onexfabricapi.FabricPodProfile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='onexfabricapi.FabricPodProfile.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035 \242\001\035Description missing in models', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pod_switch', full_name='onexfabricapi.FabricPodProfile.pod_switch', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035 \242\001\035Description missing in models', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rack', full_name='onexfabricapi.FabricPodProfile.rack', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035 \242\001\035Description missing in models', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\212\246\035\037R\035Description missing in models',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_name', full_name='onexfabricapi.FabricPodProfile._name',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_pod_switch', full_name='onexfabricapi.FabricPodProfile._pod_switch',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_rack', full_name='onexfabricapi.FabricPodProfile._rack',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3086,
  serialized_end=3410,
)


_FABRICPODSWITCH_UPLINKECMPMODE = _descriptor.Descriptor(
  name='UplinkEcmpMode',
  full_name='onexfabricapi.FabricPodSwitch.UplinkEcmpMode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FABRICPODSWITCH_UPLINKECMPMODE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4474,
  serialized_end=4569,
)

_FABRICPODSWITCH_DOWNLINKECMPMODE = _descriptor.Descriptor(
  name='DownlinkEcmpMode',
  full_name='onexfabricapi.FabricPodSwitch.DownlinkEcmpMode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FABRICPODSWITCH_DOWNLINKECMPMODE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2671,
  serialized_end=2768,
)

_FABRICPODSWITCH = _descriptor.Descriptor(
  name='FabricPodSwitch',
  full_name='onexfabricapi.FabricPodSwitch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='count', full_name='onexfabricapi.FabricPodSwitch.count', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035\003R\0011\222\246\035 \242\001\035Description missing in models', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pod_to_spine_oversubscription', full_name='onexfabricapi.FabricPodSwitch.pod_to_spine_oversubscription', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035-\242\001*oversubscription ratio of the pod switches', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uplink_ecmp_mode', full_name='onexfabricapi.FabricPodSwitch.uplink_ecmp_mode', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035\210\002\242\001\204\002The algorithm for packet distribution over ECMP links.\n- random_spray randomly puts each packet on an ECMP member links \n- hash_3_tuple is a 3 tuple hash of ipv4 src, dst, protocol\n- hash_5_tuple is static_hash_ipv4_l4 but a different resulting RTAG7 hash mode', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='downlink_ecmp_mode', full_name='onexfabricapi.FabricPodSwitch.downlink_ecmp_mode', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035\210\002\242\001\204\002The algorithm for packet distribution over ECMP links.\n- random_spray randomly puts each packet on an ECMP member links \n- hash_3_tuple is a 3 tuple hash of ipv4 src, dst, protocol\n- hash_5_tuple is static_hash_ipv4_l4 but a different resulting RTAG7 hash mode', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qos_profile_name', full_name='onexfabricapi.FabricPodSwitch.qos_profile_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035\177\242\001|The name of a qos profile associated with this pod switch.\n\nx-constraint:\n- #/components/schemas/QosProfile/properties/name\n', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FABRICPODSWITCH_UPLINKECMPMODE, _FABRICPODSWITCH_DOWNLINKECMPMODE, ],
  enum_types=[
  ],
  serialized_options=b'\212\246\035\037R\035Description missing in models',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_count', full_name='onexfabricapi.FabricPodSwitch._count',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_pod_to_spine_oversubscription', full_name='onexfabricapi.FabricPodSwitch._pod_to_spine_oversubscription',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_uplink_ecmp_mode', full_name='onexfabricapi.FabricPodSwitch._uplink_ecmp_mode',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_downlink_ecmp_mode', full_name='onexfabricapi.FabricPodSwitch._downlink_ecmp_mode',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_qos_profile_name', full_name='onexfabricapi.FabricPodSwitch._qos_profile_name',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3413,
  serialized_end=4814,
)


_FABRICRACK = _descriptor.Descriptor(
  name='FabricRack',
  full_name='onexfabricapi.FabricRack',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='count', full_name='onexfabricapi.FabricRack.count', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035\003R\0011\222\246\035-\242\001*number of racks (and thus ToRs) in the pod', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rack_profile_names', full_name='onexfabricapi.FabricRack.rack_profile_names', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\0358\242\0015The names of rack profiles associated with this rack.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\212\246\035\037R\035Description missing in models',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_count', full_name='onexfabricapi.FabricRack._count',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=4817,
  serialized_end=5044,
)


_FABRICRACKPROFILE_TORUPLINKECMPMODE = _descriptor.Descriptor(
  name='TorUplinkEcmpMode',
  full_name='onexfabricapi.FabricRackProfile.TorUplinkEcmpMode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FABRICRACKPROFILE_TORUPLINKECMPMODE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6130,
  serialized_end=6228,
)

_FABRICRACKPROFILE_TORDOWNLINKECMPMODE = _descriptor.Descriptor(
  name='TorDownlinkEcmpMode',
  full_name='onexfabricapi.FabricRackProfile.TorDownlinkEcmpMode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FABRICRACKPROFILE_TORDOWNLINKECMPMODE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6230,
  serialized_end=6330,
)

_FABRICRACKPROFILE = _descriptor.Descriptor(
  name='FabricRackProfile',
  full_name='onexfabricapi.FabricRackProfile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='onexfabricapi.FabricRackProfile.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035 \242\001\035Description missing in models', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tor_uplink_ecmp_mode', full_name='onexfabricapi.FabricRackProfile.tor_uplink_ecmp_mode', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035\210\002\242\001\204\002The algorithm for packet distribution over ECMP links.\n- random_spray randomly puts each packet on an ECMP member links \n- hash_3_tuple is a 3 tuple hash of ipv4 src, dst, protocol\n- hash_5_tuple is static_hash_ipv4_l4 but a different resulting RTAG7 hash mode', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tor_downlink_ecmp_mode', full_name='onexfabricapi.FabricRackProfile.tor_downlink_ecmp_mode', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035\210\002\242\001\204\002The algorithm for packet distribution over ECMP links.\n- random_spray randomly puts each packet on an ECMP member links \n- hash_3_tuple is a 3 tuple hash of ipv4 src, dst, protocol\n- hash_5_tuple is static_hash_ipv4_l4 but a different resulting RTAG7 hash mode', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tor_qos_profile_name', full_name='onexfabricapi.FabricRackProfile.tor_qos_profile_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035\204\001\242\001\200\001The name of a qos profile associated with the ToR of this rack\n\nx-constraint:\n- #/components/schemas/QosProfile/properties/name\n', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tor_to_pod_oversubscription', full_name='onexfabricapi.FabricRackProfile.tor_to_pod_oversubscription', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035/\242\001,The oversubscription ratio of the ToR switch', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FABRICRACKPROFILE_TORUPLINKECMPMODE, _FABRICRACKPROFILE_TORDOWNLINKECMPMODE, ],
  enum_types=[
  ],
  serialized_options=b'\212\246\035\037R\035Description missing in models',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_name', full_name='onexfabricapi.FabricRackProfile._name',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_tor_uplink_ecmp_mode', full_name='onexfabricapi.FabricRackProfile._tor_uplink_ecmp_mode',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_tor_downlink_ecmp_mode', full_name='onexfabricapi.FabricRackProfile._tor_downlink_ecmp_mode',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_tor_qos_profile_name', full_name='onexfabricapi.FabricRackProfile._tor_qos_profile_name',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_tor_to_pod_oversubscription', full_name='onexfabricapi.FabricRackProfile._tor_to_pod_oversubscription',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=5047,
  serialized_end=6485,
)


_FABRICQOSPROFILE = _descriptor.Descriptor(
  name='FabricQosProfile',
  full_name='onexfabricapi.FabricQosProfile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='onexfabricapi.FabricQosProfile.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035 \242\001\035Description missing in models', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ingress_admission', full_name='onexfabricapi.FabricQosProfile.ingress_admission', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035 \242\001\035Description missing in models', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scheduler', full_name='onexfabricapi.FabricQosProfile.scheduler', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035 \242\001\035Description missing in models', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='packet_classification', full_name='onexfabricapi.FabricQosProfile.packet_classification', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035 \242\001\035Description missing in models', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\212\246\035\037R\035Description missing in models',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_ingress_admission', full_name='onexfabricapi.FabricQosProfile._ingress_admission',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_scheduler', full_name='onexfabricapi.FabricQosProfile._scheduler',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_packet_classification', full_name='onexfabricapi.FabricQosProfile._packet_classification',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=6488,
  serialized_end=7007,
)


_FABRICQOSPROFILEINGRESSADMISSION = _descriptor.Descriptor(
  name='FabricQosProfileIngressAdmission',
  full_name='onexfabricapi.FabricQosProfileIngressAdmission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reserved_buffer_bytes', full_name='onexfabricapi.FabricQosProfileIngressAdmission.reserved_buffer_bytes', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035\003R\0010\222\246\035R\242\001OBuffer space (in bytes) reserved for each port that this Qos profile applies to', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shared_buffer_bytes', full_name='onexfabricapi.FabricQosProfileIngressAdmission.shared_buffer_bytes', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035\003R\0010\222\246\0355\242\0012Amount of shared buffer space (in bytes) available', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\212\246\035\037R\035Description missing in models',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_reserved_buffer_bytes', full_name='onexfabricapi.FabricQosProfileIngressAdmission._reserved_buffer_bytes',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_shared_buffer_bytes', full_name='onexfabricapi.FabricQosProfileIngressAdmission._shared_buffer_bytes',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=7010,
  serialized_end=7363,
)


_FABRICQOSPROFILESCHEDULER_SCHEDULERMODE = _descriptor.Descriptor(
  name='SchedulerMode',
  full_name='onexfabricapi.FabricQosProfileScheduler.SchedulerMode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FABRICQOSPROFILESCHEDULER_SCHEDULERMODE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7580,
  serialized_end=7667,
)

_FABRICQOSPROFILESCHEDULER = _descriptor.Descriptor(
  name='FabricQosProfileScheduler',
  full_name='onexfabricapi.FabricQosProfileScheduler',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scheduler_mode', full_name='onexfabricapi.FabricQosProfileScheduler.scheduler_mode', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035#\242\001 The queue scheduling discipline ', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight_list', full_name='onexfabricapi.FabricQosProfileScheduler.weight_list', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035\032\242\001\027A list of queue weights', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FABRICQOSPROFILESCHEDULER_SCHEDULERMODE, ],
  enum_types=[
  ],
  serialized_options=b'\212\246\035\037R\035Description missing in models',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_scheduler_mode', full_name='onexfabricapi.FabricQosProfileScheduler._scheduler_mode',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=7366,
  serialized_end=7723,
)


_FABRICQOSPROFILEPACKETCLASSIFICATION = _descriptor.Descriptor(
  name='FabricQosProfilePacketClassification',
  full_name='onexfabricapi.FabricQosProfilePacketClassification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='map_dscp_to_traffic_class', full_name='onexfabricapi.FabricQosProfilePacketClassification.map_dscp_to_traffic_class', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035 \242\001\035Description missing in models', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='map_traffic_class_to_queue', full_name='onexfabricapi.FabricQosProfilePacketClassification.map_traffic_class_to_queue', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035 \242\001\035Description missing in models', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\212\246\035\037R\035Description missing in models',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_map_dscp_to_traffic_class', full_name='onexfabricapi.FabricQosProfilePacketClassification._map_dscp_to_traffic_class',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_map_traffic_class_to_queue', full_name='onexfabricapi.FabricQosProfilePacketClassification._map_traffic_class_to_queue',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=7726,
  serialized_end=8133,
)


_FABRICQOSPROFILEPACKETCLASSIFICATIONMAP = _descriptor.Descriptor(
  name='FabricQosProfilePacketClassificationMap',
  full_name='onexfabricapi.FabricQosProfilePacketClassificationMap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\212\246\035\037R\035Description missing in models',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8135,
  serialized_end=8213,
)


_SWITCHHOSTLINK_CHOICE = _descriptor.Descriptor(
  name='Choice',
  full_name='onexfabricapi.SwitchHostLink.Choice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SWITCHHOSTLINK_CHOICE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8891,
  serialized_end=8954,
)

_SWITCHHOSTLINK = _descriptor.Descriptor(
  name='SwitchHostLink',
  full_name='onexfabricapi.SwitchHostLink',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_name', full_name='onexfabricapi.SwitchHostLink.host_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035A\242\001>TBD\n\nx-constraint:\n- #components/schemas/Host/properties/name\n', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='front_panel_port', full_name='onexfabricapi.SwitchHostLink.front_panel_port', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035J\242\001GOptional front panel port number, if fabric is rendered on physical box', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='choice', full_name='onexfabricapi.SwitchHostLink.choice', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035\022R\020Choice.Enum.rack\222\246\035 \242\001\035Description missing in models', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spine', full_name='onexfabricapi.SwitchHostLink.spine', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035p\242\001mOne based index of the spine switch based on the number of spines \nconfigured in the spine_pod_rack topology.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pod', full_name='onexfabricapi.SwitchHostLink.pod', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035 \242\001\035Description missing in models', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rack', full_name='onexfabricapi.SwitchHostLink.rack', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035 \242\001\035Description missing in models', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SWITCHHOSTLINK_CHOICE, ],
  enum_types=[
  ],
  serialized_options=b'\212\246\035WRUThe ingress point of a host which is the index of a spine switch, \na pod/rack switch.',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_front_panel_port', full_name='onexfabricapi.SwitchHostLink._front_panel_port',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_choice', full_name='onexfabricapi.SwitchHostLink._choice',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_spine', full_name='onexfabricapi.SwitchHostLink._spine',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_pod', full_name='onexfabricapi.SwitchHostLink._pod',
      index=3, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_rack', full_name='onexfabricapi.SwitchHostLink._rack',
      index=4, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=8216,
  serialized_end=9106,
)


_SWITCHHOSTLINKSWITCHREF = _descriptor.Descriptor(
  name='SwitchHostLinkSwitchRef',
  full_name='onexfabricapi.SwitchHostLinkSwitchRef',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pod_index', full_name='onexfabricapi.SwitchHostLinkSwitchRef.pod_index', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035\003R\0011\222\246\035G\242\001DOne-based index of the pod based on the number of pods in the fabric', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='switch_index', full_name='onexfabricapi.SwitchHostLinkSwitchRef.switch_index', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222\246\035\003R\0011\222\246\035A\242\001>One-based index of the pod or rack switch in the indicated pod', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\212\246\0356R4Location of the switch based on pod and switch index',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_pod_index', full_name='onexfabricapi.SwitchHostLinkSwitchRef._pod_index',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_switch_index', full_name='onexfabricapi.SwitchHostLinkSwitchRef._switch_index',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=9109,
  serialized_end=9438,
)


_SETCONFIGREQUEST = _descriptor.Descriptor(
  name='SetConfigRequest',
  full_name='onexfabricapi.SetConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='onexfabricapi.SetConfigRequest.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9440,
  serialized_end=9497,
)


_SETCONFIGRESPONSE = _descriptor.Descriptor(
  name='SetConfigResponse',
  full_name='onexfabricapi.SetConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status_code_400', full_name='onexfabricapi.SetConfigResponse.status_code_400', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_code_500', full_name='onexfabricapi.SetConfigResponse.status_code_500', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_code_200', full_name='onexfabricapi.SetConfigResponse.status_code_200', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_status_code_400', full_name='onexfabricapi.SetConfigResponse._status_code_400',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_status_code_500', full_name='onexfabricapi.SetConfigResponse._status_code_500',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_status_code_200', full_name='onexfabricapi.SetConfigResponse._status_code_200',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=9500,
  serialized_end=9758,
)


_GETCONFIGRESPONSE = _descriptor.Descriptor(
  name='GetConfigResponse',
  full_name='onexfabricapi.GetConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status_code_200', full_name='onexfabricapi.GetConfigResponse.status_code_200', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_code_400', full_name='onexfabricapi.GetConfigResponse.status_code_400', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_code_500', full_name='onexfabricapi.GetConfigResponse.status_code_500', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_status_code_200', full_name='onexfabricapi.GetConfigResponse._status_code_200',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_status_code_400', full_name='onexfabricapi.GetConfigResponse._status_code_400',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_status_code_500', full_name='onexfabricapi.GetConfigResponse._status_code_500',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=9761,
  serialized_end=10011,
)

_GLOBALNAMEDOBJECT.oneofs_by_name['_name'].fields.append(
  _GLOBALNAMEDOBJECT.fields_by_name['name'])
_GLOBALNAMEDOBJECT.fields_by_name['name'].containing_oneof = _GLOBALNAMEDOBJECT.oneofs_by_name['_name']
_CONFIG.fields_by_name['hosts'].message_type = _HOST
_CONFIG.fields_by_name['fabric'].message_type = _FABRIC
_CONFIG.oneofs_by_name['_fabric'].fields.append(
  _CONFIG.fields_by_name['fabric'])
_CONFIG.fields_by_name['fabric'].containing_oneof = _CONFIG.oneofs_by_name['_fabric']
_HOST.oneofs_by_name['_prefix'].fields.append(
  _HOST.fields_by_name['prefix'])
_HOST.fields_by_name['prefix'].containing_oneof = _HOST.oneofs_by_name['_prefix']
_FABRIC_CHOICE.containing_type = _FABRIC
_FABRIC_CHOICE_ENUM.containing_type = _FABRIC_CHOICE
_FABRIC.fields_by_name['choice'].enum_type = _FABRIC_CHOICE_ENUM
_FABRIC.fields_by_name['spine_pod_rack'].message_type = _FABRICSPINEPODRACK
_FABRIC.fields_by_name['qos_profiles'].message_type = _FABRICQOSPROFILE
_FABRIC.oneofs_by_name['_choice'].fields.append(
  _FABRIC.fields_by_name['choice'])
_FABRIC.fields_by_name['choice'].containing_oneof = _FABRIC.oneofs_by_name['_choice']
_FABRIC.oneofs_by_name['_spine_pod_rack'].fields.append(
  _FABRIC.fields_by_name['spine_pod_rack'])
_FABRIC.fields_by_name['spine_pod_rack'].containing_oneof = _FABRIC.oneofs_by_name['_spine_pod_rack']
_FABRICSPINEPODRACK.fields_by_name['spines'].message_type = _FABRICSPINE
_FABRICSPINEPODRACK.fields_by_name['pods'].message_type = _FABRICPOD
_FABRICSPINEPODRACK.fields_by_name['host_links'].message_type = _SWITCHHOSTLINK
_FABRICSPINEPODRACK.fields_by_name['pod_profiles'].message_type = _FABRICPODPROFILE
_FABRICSPINEPODRACK.fields_by_name['rack_profiles'].message_type = _FABRICRACKPROFILE
_FABRICSPINE_DOWNLINKECMPMODE.containing_type = _FABRICSPINE
_FABRICSPINE_DOWNLINKECMPMODE_ENUM.containing_type = _FABRICSPINE_DOWNLINKECMPMODE
_FABRICSPINE.fields_by_name['downlink_ecmp_mode'].enum_type = _FABRICSPINE_DOWNLINKECMPMODE_ENUM
_FABRICSPINE.oneofs_by_name['_count'].fields.append(
  _FABRICSPINE.fields_by_name['count'])
_FABRICSPINE.fields_by_name['count'].containing_oneof = _FABRICSPINE.oneofs_by_name['_count']
_FABRICSPINE.oneofs_by_name['_downlink_ecmp_mode'].fields.append(
  _FABRICSPINE.fields_by_name['downlink_ecmp_mode'])
_FABRICSPINE.fields_by_name['downlink_ecmp_mode'].containing_oneof = _FABRICSPINE.oneofs_by_name['_downlink_ecmp_mode']
_FABRICSPINE.oneofs_by_name['_qos_profile_name'].fields.append(
  _FABRICSPINE.fields_by_name['qos_profile_name'])
_FABRICSPINE.fields_by_name['qos_profile_name'].containing_oneof = _FABRICSPINE.oneofs_by_name['_qos_profile_name']
_FABRICPOD.oneofs_by_name['_count'].fields.append(
  _FABRICPOD.fields_by_name['count'])
_FABRICPOD.fields_by_name['count'].containing_oneof = _FABRICPOD.oneofs_by_name['_count']
_FABRICPODPROFILE.fields_by_name['pod_switch'].message_type = _FABRICPODSWITCH
_FABRICPODPROFILE.fields_by_name['rack'].message_type = _FABRICRACK
_FABRICPODPROFILE.oneofs_by_name['_name'].fields.append(
  _FABRICPODPROFILE.fields_by_name['name'])
_FABRICPODPROFILE.fields_by_name['name'].containing_oneof = _FABRICPODPROFILE.oneofs_by_name['_name']
_FABRICPODPROFILE.oneofs_by_name['_pod_switch'].fields.append(
  _FABRICPODPROFILE.fields_by_name['pod_switch'])
_FABRICPODPROFILE.fields_by_name['pod_switch'].containing_oneof = _FABRICPODPROFILE.oneofs_by_name['_pod_switch']
_FABRICPODPROFILE.oneofs_by_name['_rack'].fields.append(
  _FABRICPODPROFILE.fields_by_name['rack'])
_FABRICPODPROFILE.fields_by_name['rack'].containing_oneof = _FABRICPODPROFILE.oneofs_by_name['_rack']
_FABRICPODSWITCH_UPLINKECMPMODE.containing_type = _FABRICPODSWITCH
_FABRICPODSWITCH_UPLINKECMPMODE_ENUM.containing_type = _FABRICPODSWITCH_UPLINKECMPMODE
_FABRICPODSWITCH_DOWNLINKECMPMODE.containing_type = _FABRICPODSWITCH
_FABRICPODSWITCH_DOWNLINKECMPMODE_ENUM.containing_type = _FABRICPODSWITCH_DOWNLINKECMPMODE
_FABRICPODSWITCH.fields_by_name['uplink_ecmp_mode'].enum_type = _FABRICPODSWITCH_UPLINKECMPMODE_ENUM
_FABRICPODSWITCH.fields_by_name['downlink_ecmp_mode'].enum_type = _FABRICPODSWITCH_DOWNLINKECMPMODE_ENUM
_FABRICPODSWITCH.oneofs_by_name['_count'].fields.append(
  _FABRICPODSWITCH.fields_by_name['count'])
_FABRICPODSWITCH.fields_by_name['count'].containing_oneof = _FABRICPODSWITCH.oneofs_by_name['_count']
_FABRICPODSWITCH.oneofs_by_name['_pod_to_spine_oversubscription'].fields.append(
  _FABRICPODSWITCH.fields_by_name['pod_to_spine_oversubscription'])
_FABRICPODSWITCH.fields_by_name['pod_to_spine_oversubscription'].containing_oneof = _FABRICPODSWITCH.oneofs_by_name['_pod_to_spine_oversubscription']
_FABRICPODSWITCH.oneofs_by_name['_uplink_ecmp_mode'].fields.append(
  _FABRICPODSWITCH.fields_by_name['uplink_ecmp_mode'])
_FABRICPODSWITCH.fields_by_name['uplink_ecmp_mode'].containing_oneof = _FABRICPODSWITCH.oneofs_by_name['_uplink_ecmp_mode']
_FABRICPODSWITCH.oneofs_by_name['_downlink_ecmp_mode'].fields.append(
  _FABRICPODSWITCH.fields_by_name['downlink_ecmp_mode'])
_FABRICPODSWITCH.fields_by_name['downlink_ecmp_mode'].containing_oneof = _FABRICPODSWITCH.oneofs_by_name['_downlink_ecmp_mode']
_FABRICPODSWITCH.oneofs_by_name['_qos_profile_name'].fields.append(
  _FABRICPODSWITCH.fields_by_name['qos_profile_name'])
_FABRICPODSWITCH.fields_by_name['qos_profile_name'].containing_oneof = _FABRICPODSWITCH.oneofs_by_name['_qos_profile_name']
_FABRICRACK.oneofs_by_name['_count'].fields.append(
  _FABRICRACK.fields_by_name['count'])
_FABRICRACK.fields_by_name['count'].containing_oneof = _FABRICRACK.oneofs_by_name['_count']
_FABRICRACKPROFILE_TORUPLINKECMPMODE.containing_type = _FABRICRACKPROFILE
_FABRICRACKPROFILE_TORUPLINKECMPMODE_ENUM.containing_type = _FABRICRACKPROFILE_TORUPLINKECMPMODE
_FABRICRACKPROFILE_TORDOWNLINKECMPMODE.containing_type = _FABRICRACKPROFILE
_FABRICRACKPROFILE_TORDOWNLINKECMPMODE_ENUM.containing_type = _FABRICRACKPROFILE_TORDOWNLINKECMPMODE
_FABRICRACKPROFILE.fields_by_name['tor_uplink_ecmp_mode'].enum_type = _FABRICRACKPROFILE_TORUPLINKECMPMODE_ENUM
_FABRICRACKPROFILE.fields_by_name['tor_downlink_ecmp_mode'].enum_type = _FABRICRACKPROFILE_TORDOWNLINKECMPMODE_ENUM
_FABRICRACKPROFILE.oneofs_by_name['_name'].fields.append(
  _FABRICRACKPROFILE.fields_by_name['name'])
_FABRICRACKPROFILE.fields_by_name['name'].containing_oneof = _FABRICRACKPROFILE.oneofs_by_name['_name']
_FABRICRACKPROFILE.oneofs_by_name['_tor_uplink_ecmp_mode'].fields.append(
  _FABRICRACKPROFILE.fields_by_name['tor_uplink_ecmp_mode'])
_FABRICRACKPROFILE.fields_by_name['tor_uplink_ecmp_mode'].containing_oneof = _FABRICRACKPROFILE.oneofs_by_name['_tor_uplink_ecmp_mode']
_FABRICRACKPROFILE.oneofs_by_name['_tor_downlink_ecmp_mode'].fields.append(
  _FABRICRACKPROFILE.fields_by_name['tor_downlink_ecmp_mode'])
_FABRICRACKPROFILE.fields_by_name['tor_downlink_ecmp_mode'].containing_oneof = _FABRICRACKPROFILE.oneofs_by_name['_tor_downlink_ecmp_mode']
_FABRICRACKPROFILE.oneofs_by_name['_tor_qos_profile_name'].fields.append(
  _FABRICRACKPROFILE.fields_by_name['tor_qos_profile_name'])
_FABRICRACKPROFILE.fields_by_name['tor_qos_profile_name'].containing_oneof = _FABRICRACKPROFILE.oneofs_by_name['_tor_qos_profile_name']
_FABRICRACKPROFILE.oneofs_by_name['_tor_to_pod_oversubscription'].fields.append(
  _FABRICRACKPROFILE.fields_by_name['tor_to_pod_oversubscription'])
_FABRICRACKPROFILE.fields_by_name['tor_to_pod_oversubscription'].containing_oneof = _FABRICRACKPROFILE.oneofs_by_name['_tor_to_pod_oversubscription']
_FABRICQOSPROFILE.fields_by_name['ingress_admission'].message_type = _FABRICQOSPROFILEINGRESSADMISSION
_FABRICQOSPROFILE.fields_by_name['scheduler'].message_type = _FABRICQOSPROFILESCHEDULER
_FABRICQOSPROFILE.fields_by_name['packet_classification'].message_type = _FABRICQOSPROFILEPACKETCLASSIFICATION
_FABRICQOSPROFILE.oneofs_by_name['_ingress_admission'].fields.append(
  _FABRICQOSPROFILE.fields_by_name['ingress_admission'])
_FABRICQOSPROFILE.fields_by_name['ingress_admission'].containing_oneof = _FABRICQOSPROFILE.oneofs_by_name['_ingress_admission']
_FABRICQOSPROFILE.oneofs_by_name['_scheduler'].fields.append(
  _FABRICQOSPROFILE.fields_by_name['scheduler'])
_FABRICQOSPROFILE.fields_by_name['scheduler'].containing_oneof = _FABRICQOSPROFILE.oneofs_by_name['_scheduler']
_FABRICQOSPROFILE.oneofs_by_name['_packet_classification'].fields.append(
  _FABRICQOSPROFILE.fields_by_name['packet_classification'])
_FABRICQOSPROFILE.fields_by_name['packet_classification'].containing_oneof = _FABRICQOSPROFILE.oneofs_by_name['_packet_classification']
_FABRICQOSPROFILEINGRESSADMISSION.oneofs_by_name['_reserved_buffer_bytes'].fields.append(
  _FABRICQOSPROFILEINGRESSADMISSION.fields_by_name['reserved_buffer_bytes'])
_FABRICQOSPROFILEINGRESSADMISSION.fields_by_name['reserved_buffer_bytes'].containing_oneof = _FABRICQOSPROFILEINGRESSADMISSION.oneofs_by_name['_reserved_buffer_bytes']
_FABRICQOSPROFILEINGRESSADMISSION.oneofs_by_name['_shared_buffer_bytes'].fields.append(
  _FABRICQOSPROFILEINGRESSADMISSION.fields_by_name['shared_buffer_bytes'])
_FABRICQOSPROFILEINGRESSADMISSION.fields_by_name['shared_buffer_bytes'].containing_oneof = _FABRICQOSPROFILEINGRESSADMISSION.oneofs_by_name['_shared_buffer_bytes']
_FABRICQOSPROFILESCHEDULER_SCHEDULERMODE.containing_type = _FABRICQOSPROFILESCHEDULER
_FABRICQOSPROFILESCHEDULER_SCHEDULERMODE_ENUM.containing_type = _FABRICQOSPROFILESCHEDULER_SCHEDULERMODE
_FABRICQOSPROFILESCHEDULER.fields_by_name['scheduler_mode'].enum_type = _FABRICQOSPROFILESCHEDULER_SCHEDULERMODE_ENUM
_FABRICQOSPROFILESCHEDULER.oneofs_by_name['_scheduler_mode'].fields.append(
  _FABRICQOSPROFILESCHEDULER.fields_by_name['scheduler_mode'])
_FABRICQOSPROFILESCHEDULER.fields_by_name['scheduler_mode'].containing_oneof = _FABRICQOSPROFILESCHEDULER.oneofs_by_name['_scheduler_mode']
_FABRICQOSPROFILEPACKETCLASSIFICATION.fields_by_name['map_dscp_to_traffic_class'].message_type = _FABRICQOSPROFILEPACKETCLASSIFICATIONMAP
_FABRICQOSPROFILEPACKETCLASSIFICATION.fields_by_name['map_traffic_class_to_queue'].message_type = _FABRICQOSPROFILEPACKETCLASSIFICATIONMAP
_FABRICQOSPROFILEPACKETCLASSIFICATION.oneofs_by_name['_map_dscp_to_traffic_class'].fields.append(
  _FABRICQOSPROFILEPACKETCLASSIFICATION.fields_by_name['map_dscp_to_traffic_class'])
_FABRICQOSPROFILEPACKETCLASSIFICATION.fields_by_name['map_dscp_to_traffic_class'].containing_oneof = _FABRICQOSPROFILEPACKETCLASSIFICATION.oneofs_by_name['_map_dscp_to_traffic_class']
_FABRICQOSPROFILEPACKETCLASSIFICATION.oneofs_by_name['_map_traffic_class_to_queue'].fields.append(
  _FABRICQOSPROFILEPACKETCLASSIFICATION.fields_by_name['map_traffic_class_to_queue'])
_FABRICQOSPROFILEPACKETCLASSIFICATION.fields_by_name['map_traffic_class_to_queue'].containing_oneof = _FABRICQOSPROFILEPACKETCLASSIFICATION.oneofs_by_name['_map_traffic_class_to_queue']
_SWITCHHOSTLINK_CHOICE.containing_type = _SWITCHHOSTLINK
_SWITCHHOSTLINK_CHOICE_ENUM.containing_type = _SWITCHHOSTLINK_CHOICE
_SWITCHHOSTLINK.fields_by_name['choice'].enum_type = _SWITCHHOSTLINK_CHOICE_ENUM
_SWITCHHOSTLINK.fields_by_name['pod'].message_type = _SWITCHHOSTLINKSWITCHREF
_SWITCHHOSTLINK.fields_by_name['rack'].message_type = _SWITCHHOSTLINKSWITCHREF
_SWITCHHOSTLINK.oneofs_by_name['_front_panel_port'].fields.append(
  _SWITCHHOSTLINK.fields_by_name['front_panel_port'])
_SWITCHHOSTLINK.fields_by_name['front_panel_port'].containing_oneof = _SWITCHHOSTLINK.oneofs_by_name['_front_panel_port']
_SWITCHHOSTLINK.oneofs_by_name['_choice'].fields.append(
  _SWITCHHOSTLINK.fields_by_name['choice'])
_SWITCHHOSTLINK.fields_by_name['choice'].containing_oneof = _SWITCHHOSTLINK.oneofs_by_name['_choice']
_SWITCHHOSTLINK.oneofs_by_name['_spine'].fields.append(
  _SWITCHHOSTLINK.fields_by_name['spine'])
_SWITCHHOSTLINK.fields_by_name['spine'].containing_oneof = _SWITCHHOSTLINK.oneofs_by_name['_spine']
_SWITCHHOSTLINK.oneofs_by_name['_pod'].fields.append(
  _SWITCHHOSTLINK.fields_by_name['pod'])
_SWITCHHOSTLINK.fields_by_name['pod'].containing_oneof = _SWITCHHOSTLINK.oneofs_by_name['_pod']
_SWITCHHOSTLINK.oneofs_by_name['_rack'].fields.append(
  _SWITCHHOSTLINK.fields_by_name['rack'])
_SWITCHHOSTLINK.fields_by_name['rack'].containing_oneof = _SWITCHHOSTLINK.oneofs_by_name['_rack']
_SWITCHHOSTLINKSWITCHREF.oneofs_by_name['_pod_index'].fields.append(
  _SWITCHHOSTLINKSWITCHREF.fields_by_name['pod_index'])
_SWITCHHOSTLINKSWITCHREF.fields_by_name['pod_index'].containing_oneof = _SWITCHHOSTLINKSWITCHREF.oneofs_by_name['_pod_index']
_SWITCHHOSTLINKSWITCHREF.oneofs_by_name['_switch_index'].fields.append(
  _SWITCHHOSTLINKSWITCHREF.fields_by_name['switch_index'])
_SWITCHHOSTLINKSWITCHREF.fields_by_name['switch_index'].containing_oneof = _SWITCHHOSTLINKSWITCHREF.oneofs_by_name['_switch_index']
_SETCONFIGREQUEST.fields_by_name['config'].message_type = _CONFIG
_SETCONFIGRESPONSE.fields_by_name['status_code_400'].message_type = _ERRORDETAILS
_SETCONFIGRESPONSE.fields_by_name['status_code_500'].message_type = _ERRORDETAILS
_SETCONFIGRESPONSE.fields_by_name['status_code_200'].message_type = _WARNINGDETAILS
_SETCONFIGRESPONSE.oneofs_by_name['_status_code_400'].fields.append(
  _SETCONFIGRESPONSE.fields_by_name['status_code_400'])
_SETCONFIGRESPONSE.fields_by_name['status_code_400'].containing_oneof = _SETCONFIGRESPONSE.oneofs_by_name['_status_code_400']
_SETCONFIGRESPONSE.oneofs_by_name['_status_code_500'].fields.append(
  _SETCONFIGRESPONSE.fields_by_name['status_code_500'])
_SETCONFIGRESPONSE.fields_by_name['status_code_500'].containing_oneof = _SETCONFIGRESPONSE.oneofs_by_name['_status_code_500']
_SETCONFIGRESPONSE.oneofs_by_name['_status_code_200'].fields.append(
  _SETCONFIGRESPONSE.fields_by_name['status_code_200'])
_SETCONFIGRESPONSE.fields_by_name['status_code_200'].containing_oneof = _SETCONFIGRESPONSE.oneofs_by_name['_status_code_200']
_GETCONFIGRESPONSE.fields_by_name['status_code_200'].message_type = _CONFIG
_GETCONFIGRESPONSE.fields_by_name['status_code_400'].message_type = _ERRORDETAILS
_GETCONFIGRESPONSE.fields_by_name['status_code_500'].message_type = _ERRORDETAILS
_GETCONFIGRESPONSE.oneofs_by_name['_status_code_200'].fields.append(
  _GETCONFIGRESPONSE.fields_by_name['status_code_200'])
_GETCONFIGRESPONSE.fields_by_name['status_code_200'].containing_oneof = _GETCONFIGRESPONSE.oneofs_by_name['_status_code_200']
_GETCONFIGRESPONSE.oneofs_by_name['_status_code_400'].fields.append(
  _GETCONFIGRESPONSE.fields_by_name['status_code_400'])
_GETCONFIGRESPONSE.fields_by_name['status_code_400'].containing_oneof = _GETCONFIGRESPONSE.oneofs_by_name['_status_code_400']
_GETCONFIGRESPONSE.oneofs_by_name['_status_code_500'].fields.append(
  _GETCONFIGRESPONSE.fields_by_name['status_code_500'])
_GETCONFIGRESPONSE.fields_by_name['status_code_500'].containing_oneof = _GETCONFIGRESPONSE.oneofs_by_name['_status_code_500']
DESCRIPTOR.message_types_by_name['OpenApiMsgOpt'] = _OPENAPIMSGOPT
DESCRIPTOR.message_types_by_name['OpenApiFldOpt'] = _OPENAPIFLDOPT
DESCRIPTOR.message_types_by_name['OpenApiSvcOpt'] = _OPENAPISVCOPT
DESCRIPTOR.message_types_by_name['OpenApiRpcOpt'] = _OPENAPIRPCOPT
DESCRIPTOR.message_types_by_name['GlobalNamedObject'] = _GLOBALNAMEDOBJECT
DESCRIPTOR.message_types_by_name['ErrorDetails'] = _ERRORDETAILS
DESCRIPTOR.message_types_by_name['WarningDetails'] = _WARNINGDETAILS
DESCRIPTOR.message_types_by_name['Config'] = _CONFIG
DESCRIPTOR.message_types_by_name['Host'] = _HOST
DESCRIPTOR.message_types_by_name['Fabric'] = _FABRIC
DESCRIPTOR.message_types_by_name['FabricSpinePodRack'] = _FABRICSPINEPODRACK
DESCRIPTOR.message_types_by_name['FabricSpine'] = _FABRICSPINE
DESCRIPTOR.message_types_by_name['FabricPod'] = _FABRICPOD
DESCRIPTOR.message_types_by_name['FabricPodProfile'] = _FABRICPODPROFILE
DESCRIPTOR.message_types_by_name['FabricPodSwitch'] = _FABRICPODSWITCH
DESCRIPTOR.message_types_by_name['FabricRack'] = _FABRICRACK
DESCRIPTOR.message_types_by_name['FabricRackProfile'] = _FABRICRACKPROFILE
DESCRIPTOR.message_types_by_name['FabricQosProfile'] = _FABRICQOSPROFILE
DESCRIPTOR.message_types_by_name['FabricQosProfileIngressAdmission'] = _FABRICQOSPROFILEINGRESSADMISSION
DESCRIPTOR.message_types_by_name['FabricQosProfileScheduler'] = _FABRICQOSPROFILESCHEDULER
DESCRIPTOR.message_types_by_name['FabricQosProfilePacketClassification'] = _FABRICQOSPROFILEPACKETCLASSIFICATION
DESCRIPTOR.message_types_by_name['FabricQosProfilePacketClassificationMap'] = _FABRICQOSPROFILEPACKETCLASSIFICATIONMAP
DESCRIPTOR.message_types_by_name['SwitchHostLink'] = _SWITCHHOSTLINK
DESCRIPTOR.message_types_by_name['SwitchHostLinkSwitchRef'] = _SWITCHHOSTLINKSWITCHREF
DESCRIPTOR.message_types_by_name['SetConfigRequest'] = _SETCONFIGREQUEST
DESCRIPTOR.message_types_by_name['SetConfigResponse'] = _SETCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['GetConfigResponse'] = _GETCONFIGRESPONSE
DESCRIPTOR.extensions_by_name['msg_meta'] = msg_meta
DESCRIPTOR.extensions_by_name['fld_meta'] = fld_meta
DESCRIPTOR.extensions_by_name['svc_meta'] = svc_meta
DESCRIPTOR.extensions_by_name['rpc_meta'] = rpc_meta
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

OpenApiMsgOpt = _reflection.GeneratedProtocolMessageType('OpenApiMsgOpt', (_message.Message,), {
  'DESCRIPTOR' : _OPENAPIMSGOPT,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.OpenApiMsgOpt)
  })
_sym_db.RegisterMessage(OpenApiMsgOpt)

OpenApiFldOpt = _reflection.GeneratedProtocolMessageType('OpenApiFldOpt', (_message.Message,), {
  'DESCRIPTOR' : _OPENAPIFLDOPT,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.OpenApiFldOpt)
  })
_sym_db.RegisterMessage(OpenApiFldOpt)

OpenApiSvcOpt = _reflection.GeneratedProtocolMessageType('OpenApiSvcOpt', (_message.Message,), {
  'DESCRIPTOR' : _OPENAPISVCOPT,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.OpenApiSvcOpt)
  })
_sym_db.RegisterMessage(OpenApiSvcOpt)

OpenApiRpcOpt = _reflection.GeneratedProtocolMessageType('OpenApiRpcOpt', (_message.Message,), {
  'DESCRIPTOR' : _OPENAPIRPCOPT,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.OpenApiRpcOpt)
  })
_sym_db.RegisterMessage(OpenApiRpcOpt)

GlobalNamedObject = _reflection.GeneratedProtocolMessageType('GlobalNamedObject', (_message.Message,), {
  'DESCRIPTOR' : _GLOBALNAMEDOBJECT,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.GlobalNamedObject)
  })
_sym_db.RegisterMessage(GlobalNamedObject)

ErrorDetails = _reflection.GeneratedProtocolMessageType('ErrorDetails', (_message.Message,), {
  'DESCRIPTOR' : _ERRORDETAILS,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.ErrorDetails)
  })
_sym_db.RegisterMessage(ErrorDetails)

WarningDetails = _reflection.GeneratedProtocolMessageType('WarningDetails', (_message.Message,), {
  'DESCRIPTOR' : _WARNINGDETAILS,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.WarningDetails)
  })
_sym_db.RegisterMessage(WarningDetails)

Config = _reflection.GeneratedProtocolMessageType('Config', (_message.Message,), {
  'DESCRIPTOR' : _CONFIG,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.Config)
  })
_sym_db.RegisterMessage(Config)

Host = _reflection.GeneratedProtocolMessageType('Host', (_message.Message,), {
  'DESCRIPTOR' : _HOST,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.Host)
  })
_sym_db.RegisterMessage(Host)

Fabric = _reflection.GeneratedProtocolMessageType('Fabric', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _FABRIC_CHOICE,
    '__module__' : 'onexfabricapi_pb2'
    # @@protoc_insertion_point(class_scope:onexfabricapi.Fabric.Choice)
    })
  ,
  'DESCRIPTOR' : _FABRIC,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.Fabric)
  })
_sym_db.RegisterMessage(Fabric)
_sym_db.RegisterMessage(Fabric.Choice)

FabricSpinePodRack = _reflection.GeneratedProtocolMessageType('FabricSpinePodRack', (_message.Message,), {
  'DESCRIPTOR' : _FABRICSPINEPODRACK,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.FabricSpinePodRack)
  })
_sym_db.RegisterMessage(FabricSpinePodRack)

FabricSpine = _reflection.GeneratedProtocolMessageType('FabricSpine', (_message.Message,), {

  'DownlinkEcmpMode' : _reflection.GeneratedProtocolMessageType('DownlinkEcmpMode', (_message.Message,), {
    'DESCRIPTOR' : _FABRICSPINE_DOWNLINKECMPMODE,
    '__module__' : 'onexfabricapi_pb2'
    # @@protoc_insertion_point(class_scope:onexfabricapi.FabricSpine.DownlinkEcmpMode)
    })
  ,
  'DESCRIPTOR' : _FABRICSPINE,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.FabricSpine)
  })
_sym_db.RegisterMessage(FabricSpine)
_sym_db.RegisterMessage(FabricSpine.DownlinkEcmpMode)

FabricPod = _reflection.GeneratedProtocolMessageType('FabricPod', (_message.Message,), {
  'DESCRIPTOR' : _FABRICPOD,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.FabricPod)
  })
_sym_db.RegisterMessage(FabricPod)

FabricPodProfile = _reflection.GeneratedProtocolMessageType('FabricPodProfile', (_message.Message,), {
  'DESCRIPTOR' : _FABRICPODPROFILE,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.FabricPodProfile)
  })
_sym_db.RegisterMessage(FabricPodProfile)

FabricPodSwitch = _reflection.GeneratedProtocolMessageType('FabricPodSwitch', (_message.Message,), {

  'UplinkEcmpMode' : _reflection.GeneratedProtocolMessageType('UplinkEcmpMode', (_message.Message,), {
    'DESCRIPTOR' : _FABRICPODSWITCH_UPLINKECMPMODE,
    '__module__' : 'onexfabricapi_pb2'
    # @@protoc_insertion_point(class_scope:onexfabricapi.FabricPodSwitch.UplinkEcmpMode)
    })
  ,

  'DownlinkEcmpMode' : _reflection.GeneratedProtocolMessageType('DownlinkEcmpMode', (_message.Message,), {
    'DESCRIPTOR' : _FABRICPODSWITCH_DOWNLINKECMPMODE,
    '__module__' : 'onexfabricapi_pb2'
    # @@protoc_insertion_point(class_scope:onexfabricapi.FabricPodSwitch.DownlinkEcmpMode)
    })
  ,
  'DESCRIPTOR' : _FABRICPODSWITCH,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.FabricPodSwitch)
  })
_sym_db.RegisterMessage(FabricPodSwitch)
_sym_db.RegisterMessage(FabricPodSwitch.UplinkEcmpMode)
_sym_db.RegisterMessage(FabricPodSwitch.DownlinkEcmpMode)

FabricRack = _reflection.GeneratedProtocolMessageType('FabricRack', (_message.Message,), {
  'DESCRIPTOR' : _FABRICRACK,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.FabricRack)
  })
_sym_db.RegisterMessage(FabricRack)

FabricRackProfile = _reflection.GeneratedProtocolMessageType('FabricRackProfile', (_message.Message,), {

  'TorUplinkEcmpMode' : _reflection.GeneratedProtocolMessageType('TorUplinkEcmpMode', (_message.Message,), {
    'DESCRIPTOR' : _FABRICRACKPROFILE_TORUPLINKECMPMODE,
    '__module__' : 'onexfabricapi_pb2'
    # @@protoc_insertion_point(class_scope:onexfabricapi.FabricRackProfile.TorUplinkEcmpMode)
    })
  ,

  'TorDownlinkEcmpMode' : _reflection.GeneratedProtocolMessageType('TorDownlinkEcmpMode', (_message.Message,), {
    'DESCRIPTOR' : _FABRICRACKPROFILE_TORDOWNLINKECMPMODE,
    '__module__' : 'onexfabricapi_pb2'
    # @@protoc_insertion_point(class_scope:onexfabricapi.FabricRackProfile.TorDownlinkEcmpMode)
    })
  ,
  'DESCRIPTOR' : _FABRICRACKPROFILE,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.FabricRackProfile)
  })
_sym_db.RegisterMessage(FabricRackProfile)
_sym_db.RegisterMessage(FabricRackProfile.TorUplinkEcmpMode)
_sym_db.RegisterMessage(FabricRackProfile.TorDownlinkEcmpMode)

FabricQosProfile = _reflection.GeneratedProtocolMessageType('FabricQosProfile', (_message.Message,), {
  'DESCRIPTOR' : _FABRICQOSPROFILE,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.FabricQosProfile)
  })
_sym_db.RegisterMessage(FabricQosProfile)

FabricQosProfileIngressAdmission = _reflection.GeneratedProtocolMessageType('FabricQosProfileIngressAdmission', (_message.Message,), {
  'DESCRIPTOR' : _FABRICQOSPROFILEINGRESSADMISSION,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.FabricQosProfileIngressAdmission)
  })
_sym_db.RegisterMessage(FabricQosProfileIngressAdmission)

FabricQosProfileScheduler = _reflection.GeneratedProtocolMessageType('FabricQosProfileScheduler', (_message.Message,), {

  'SchedulerMode' : _reflection.GeneratedProtocolMessageType('SchedulerMode', (_message.Message,), {
    'DESCRIPTOR' : _FABRICQOSPROFILESCHEDULER_SCHEDULERMODE,
    '__module__' : 'onexfabricapi_pb2'
    # @@protoc_insertion_point(class_scope:onexfabricapi.FabricQosProfileScheduler.SchedulerMode)
    })
  ,
  'DESCRIPTOR' : _FABRICQOSPROFILESCHEDULER,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.FabricQosProfileScheduler)
  })
_sym_db.RegisterMessage(FabricQosProfileScheduler)
_sym_db.RegisterMessage(FabricQosProfileScheduler.SchedulerMode)

FabricQosProfilePacketClassification = _reflection.GeneratedProtocolMessageType('FabricQosProfilePacketClassification', (_message.Message,), {
  'DESCRIPTOR' : _FABRICQOSPROFILEPACKETCLASSIFICATION,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.FabricQosProfilePacketClassification)
  })
_sym_db.RegisterMessage(FabricQosProfilePacketClassification)

FabricQosProfilePacketClassificationMap = _reflection.GeneratedProtocolMessageType('FabricQosProfilePacketClassificationMap', (_message.Message,), {
  'DESCRIPTOR' : _FABRICQOSPROFILEPACKETCLASSIFICATIONMAP,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.FabricQosProfilePacketClassificationMap)
  })
_sym_db.RegisterMessage(FabricQosProfilePacketClassificationMap)

SwitchHostLink = _reflection.GeneratedProtocolMessageType('SwitchHostLink', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _SWITCHHOSTLINK_CHOICE,
    '__module__' : 'onexfabricapi_pb2'
    # @@protoc_insertion_point(class_scope:onexfabricapi.SwitchHostLink.Choice)
    })
  ,
  'DESCRIPTOR' : _SWITCHHOSTLINK,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.SwitchHostLink)
  })
_sym_db.RegisterMessage(SwitchHostLink)
_sym_db.RegisterMessage(SwitchHostLink.Choice)

SwitchHostLinkSwitchRef = _reflection.GeneratedProtocolMessageType('SwitchHostLinkSwitchRef', (_message.Message,), {
  'DESCRIPTOR' : _SWITCHHOSTLINKSWITCHREF,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.SwitchHostLinkSwitchRef)
  })
_sym_db.RegisterMessage(SwitchHostLinkSwitchRef)

SetConfigRequest = _reflection.GeneratedProtocolMessageType('SetConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETCONFIGREQUEST,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.SetConfigRequest)
  })
_sym_db.RegisterMessage(SetConfigRequest)

SetConfigResponse = _reflection.GeneratedProtocolMessageType('SetConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETCONFIGRESPONSE,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.SetConfigResponse)
  })
_sym_db.RegisterMessage(SetConfigResponse)

GetConfigResponse = _reflection.GeneratedProtocolMessageType('GetConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCONFIGRESPONSE,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.GetConfigResponse)
  })
_sym_db.RegisterMessage(GetConfigResponse)

msg_meta.message_type = _OPENAPIMSGOPT
google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(msg_meta)
fld_meta.message_type = _OPENAPIFLDOPT
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(fld_meta)
svc_meta.message_type = _OPENAPISVCOPT
google_dot_protobuf_dot_descriptor__pb2.ServiceOptions.RegisterExtension(svc_meta)
rpc_meta.message_type = _OPENAPIRPCOPT
google_dot_protobuf_dot_descriptor__pb2.MethodOptions.RegisterExtension(rpc_meta)

_GLOBALNAMEDOBJECT.fields_by_name['name']._options = None
_GLOBALNAMEDOBJECT._options = None
_ERRORDETAILS.fields_by_name['errors']._options = None
_ERRORDETAILS._options = None
_WARNINGDETAILS.fields_by_name['warnings']._options = None
_WARNINGDETAILS._options = None
_CONFIG.fields_by_name['hosts']._options = None
_CONFIG.fields_by_name['fabric']._options = None
_CONFIG._options = None
_HOST.fields_by_name['name']._options = None
_HOST.fields_by_name['address']._options = None
_HOST.fields_by_name['prefix']._options = None
_HOST._options = None
_FABRIC.fields_by_name['choice']._options = None
_FABRIC.fields_by_name['spine_pod_rack']._options = None
_FABRIC.fields_by_name['qos_profiles']._options = None
_FABRIC._options = None
_FABRICSPINEPODRACK.fields_by_name['spines']._options = None
_FABRICSPINEPODRACK.fields_by_name['pods']._options = None
_FABRICSPINEPODRACK.fields_by_name['host_links']._options = None
_FABRICSPINEPODRACK.fields_by_name['pod_profiles']._options = None
_FABRICSPINEPODRACK.fields_by_name['rack_profiles']._options = None
_FABRICSPINEPODRACK._options = None
_FABRICSPINE.fields_by_name['count']._options = None
_FABRICSPINE.fields_by_name['downlink_ecmp_mode']._options = None
_FABRICSPINE.fields_by_name['qos_profile_name']._options = None
_FABRICSPINE._options = None
_FABRICPOD.fields_by_name['count']._options = None
_FABRICPOD.fields_by_name['pod_profile_name']._options = None
_FABRICPOD._options = None
_FABRICPODPROFILE.fields_by_name['name']._options = None
_FABRICPODPROFILE.fields_by_name['pod_switch']._options = None
_FABRICPODPROFILE.fields_by_name['rack']._options = None
_FABRICPODPROFILE._options = None
_FABRICPODSWITCH.fields_by_name['count']._options = None
_FABRICPODSWITCH.fields_by_name['pod_to_spine_oversubscription']._options = None
_FABRICPODSWITCH.fields_by_name['uplink_ecmp_mode']._options = None
_FABRICPODSWITCH.fields_by_name['downlink_ecmp_mode']._options = None
_FABRICPODSWITCH.fields_by_name['qos_profile_name']._options = None
_FABRICPODSWITCH._options = None
_FABRICRACK.fields_by_name['count']._options = None
_FABRICRACK.fields_by_name['rack_profile_names']._options = None
_FABRICRACK._options = None
_FABRICRACKPROFILE.fields_by_name['name']._options = None
_FABRICRACKPROFILE.fields_by_name['tor_uplink_ecmp_mode']._options = None
_FABRICRACKPROFILE.fields_by_name['tor_downlink_ecmp_mode']._options = None
_FABRICRACKPROFILE.fields_by_name['tor_qos_profile_name']._options = None
_FABRICRACKPROFILE.fields_by_name['tor_to_pod_oversubscription']._options = None
_FABRICRACKPROFILE._options = None
_FABRICQOSPROFILE.fields_by_name['name']._options = None
_FABRICQOSPROFILE.fields_by_name['ingress_admission']._options = None
_FABRICQOSPROFILE.fields_by_name['scheduler']._options = None
_FABRICQOSPROFILE.fields_by_name['packet_classification']._options = None
_FABRICQOSPROFILE._options = None
_FABRICQOSPROFILEINGRESSADMISSION.fields_by_name['reserved_buffer_bytes']._options = None
_FABRICQOSPROFILEINGRESSADMISSION.fields_by_name['shared_buffer_bytes']._options = None
_FABRICQOSPROFILEINGRESSADMISSION._options = None
_FABRICQOSPROFILESCHEDULER.fields_by_name['scheduler_mode']._options = None
_FABRICQOSPROFILESCHEDULER.fields_by_name['weight_list']._options = None
_FABRICQOSPROFILESCHEDULER._options = None
_FABRICQOSPROFILEPACKETCLASSIFICATION.fields_by_name['map_dscp_to_traffic_class']._options = None
_FABRICQOSPROFILEPACKETCLASSIFICATION.fields_by_name['map_traffic_class_to_queue']._options = None
_FABRICQOSPROFILEPACKETCLASSIFICATION._options = None
_FABRICQOSPROFILEPACKETCLASSIFICATIONMAP._options = None
_SWITCHHOSTLINK.fields_by_name['host_name']._options = None
_SWITCHHOSTLINK.fields_by_name['front_panel_port']._options = None
_SWITCHHOSTLINK.fields_by_name['choice']._options = None
_SWITCHHOSTLINK.fields_by_name['spine']._options = None
_SWITCHHOSTLINK.fields_by_name['pod']._options = None
_SWITCHHOSTLINK.fields_by_name['rack']._options = None
_SWITCHHOSTLINK._options = None
_SWITCHHOSTLINKSWITCHREF.fields_by_name['pod_index']._options = None
_SWITCHHOSTLINKSWITCHREF.fields_by_name['switch_index']._options = None
_SWITCHHOSTLINKSWITCHREF._options = None

_OPENAPI = _descriptor.ServiceDescriptor(
  name='Openapi',
  full_name='onexfabricapi.Openapi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\232\246\035\037R\035Description missing in models',
  create_key=_descriptor._internal_create_key,
  serialized_start=10014,
  serialized_end=10287,
  methods=[
  _descriptor.MethodDescriptor(
    name='SetConfig',
    full_name='onexfabricapi.Openapi.SetConfig',
    index=0,
    containing_service=None,
    input_type=_SETCONFIGREQUEST,
    output_type=_SETCONFIGRESPONSE,
    serialized_options=b'\242\246\035 R\036Sets the fabric configuration.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetConfig',
    full_name='onexfabricapi.Openapi.GetConfig',
    index=1,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_GETCONFIGRESPONSE,
    serialized_options=b'\242\246\035 R\036Gets the fabric configuration.',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_OPENAPI)

DESCRIPTOR.services_by_name['Openapi'] = _OPENAPI

# @@protoc_insertion_point(module_scope)
